Module: Cimas
- Defined in:
- lib/cimas.rb,
lib/cimas/cli.rb,
lib/cimas/patch.rb,
lib/cimas/github.rb,
lib/cimas/version.rb,
lib/cimas/cli/error.rb,
lib/cimas/cli/runner.rb,
lib/cimas/repository.rb,
lib/cimas/cli/command.rb,
lib/cimas/orphan_files.rb,
lib/cimas/working_copy.rb,
lib/cimas/release_preflight.rb
Defined Under Namespace
Modules: Cli, OrphanFiles Classes: GitHub, Patch, ReleasePreflight, Repository, WorkingCopy
Constant Summary collapse
- GENERATED_HEADER_MARKER =
Ownership marker cimas writes into every file it generates and detects when deciding whether a file is cimas-managed (orphan cleanup). One definition — sync and cleanup must agree on it.
"Auto-generated by Cimas"- GENERATED_HEADER =
[ "# #{GENERATED_HEADER_MARKER}: Do not edit it manually!", "# See https://github.com/metanorma/cimas", ].join("\n").freeze
- VERSION =
"0.3.0"